@@ -14,7 +14,8 @@
 
 #include <KLocalizedString>
 
-LegendWidget::LegendWidget(QWidget *parent) : QWidget(parent)
+LegendWidget::LegendWidget(QWidget *parent)
+    : QWidget(parent)
 {
     m_update = true;
     m_dockArea = Qt::BottomDockWidgetArea;
@@ -50,7 +51,7 @@ void LegendWidget::updateContent()
     }
 
     QString gradientDesc;
-    QList< QPair<QString, QColor> > items;
+    QList<QPair<QString, QColor>> items;
     KalziumElementProperty *elementProperty = KalziumElementProperty::instance();
     // Handle different Gradients
     switch (elementProperty->gradientId()) {
@@ -59,17 +60,13 @@ void LegendWidget::updateContent()
 
     case KalziumElementProperty::SOMGradientType:
         items << qMakePair(elementProperty->gradient()->description(), QColor());
-        items << qMakePair(i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)",
-                                  "Solid"), QColor(Prefs::color_solid()));
+        items << qMakePair(i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)", "Solid"), QColor(Prefs::color_solid()));
 
-        items << qMakePair(i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)",
-                                  "Liquid"), QColor(Prefs::color_liquid()));
+        items << qMakePair(i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)", "Liquid"), QColor(Prefs::color_liquid()));
 
-        items << qMakePair(i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)",
-                                  "Vaporous"), QColor(Prefs::color_vapor()));
+        items << qMakePair(i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)", "Vaporous"), QColor(Prefs::color_vapor()));
 
-        items << qMakePair(i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)",
-                                  "Unknown"), QColor(Qt::lightGray));
+        items << qMakePair(i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)", "Unknown"), QColor(Qt::lightGray));
         break;
 
     default:
@@ -80,12 +77,14 @@ void LegendWidget::updateContent()
         }
         items << qMakePair(i18n("%1 (%2)", elementProperty->gradient()->description(), gradientDesc), QColor());
         items << qMakePair(i18nc("Minimum value of the gradient",
-                                   "Minimum: %1", QString::number(elementProperty->gradient()->minValue()) + ' ' + elementProperty->gradient()->unit()),
-                            QColor(elementProperty->gradient()->firstColor()));
+                                 "Minimum: %1",
+                                 QString::number(elementProperty->gradient()->minValue()) + ' ' + elementProperty->gradient()->unit()),
+                           QColor(elementProperty->gradient()->firstColor()));
 
         items << qMakePair(i18nc("Maximum value of the gradient",
-                                   "Maximum: %1", QString::number(elementProperty->gradient()->maxValue()) + ' ' + elementProperty->gradient()->unit()),
-                            QColor(elementProperty->gradient()->secondColor()));
+                                 "Maximum: %1",
+                                 QString::number(elementProperty->gradient()->maxValue()) + ' ' + elementProperty->gradient()->unit()),
+                           QColor(elementProperty->gradient()->secondColor()));
         break;
     }
     // schemes are always there
@@ -93,21 +92,20 @@ void LegendWidget::updateContent()
     items << elementProperty->scheme()->legendItems();
 
     updateLegendItemLayout(items);
-
 }
 
-void LegendWidget::updateLegendItemLayout(const QList<legendPair>& list)
+void LegendWidget::updateLegendItemLayout(const QList<legendPair> &list)
 {
     if (layout()) {
         delete layout();
     }
-    foreach (LegendItem * i, m_legendItemList) {
+    foreach (LegendItem *i, m_legendItemList) {
         delete i;
     }
 
     m_legendItemList.clear();
 
-    QGridLayout * layout = new QGridLayout(this);
+    auto layout = new QGridLayout(this);
     layout->setSpacing(0);
     layout->setContentsMargins(0, 0, 0, 0);
 
@@ -115,7 +113,7 @@ void LegendWidget::updateLegendItemLayout(const QList<legendPair>& list)
     int y = 0;
 
     foreach (const legendPair &pair, list) {
-        LegendItem *item = new LegendItem(pair, this);
+        auto item = new LegendItem(pair, this);
         m_legendItemList.append(item);
 
         if ((m_dockArea == Qt::BottomDockWidgetArea || m_dockArea == Qt::TopDockWidgetArea)) {
@@ -149,34 +147,32 @@ void LegendWidget::legendItemAction(QColor color)
     }
 }
 
-bool LegendWidget::isElementMatch(int element, QColor &color){
+bool LegendWidget::isElementMatch(int element, QColor &color)
+{
     QColor elementBackgroundColor;
     QColor elementBorderColor;
 
     elementBackgroundColor = KalziumElementProperty::instance()->getElementColor(element);
     elementBorderColor = KalziumElementProperty::instance()->getBorderColor(element);
 
-    switch(Prefs::colorgradientbox()){
-
-      case KalziumElementProperty::NOGRADIENT:
+    switch (Prefs::colorgradientbox()) {
+    case KalziumElementProperty::NOGRADIENT:
         if (elementBackgroundColor.operator!=(color)) {
             return true;
         }
         break;
 
-      default: // all other gradients
-        if (elementBorderColor.operator==(color) ||
-            elementBackgroundColor.operator==(color)) {
+    default: // all other gradients
+        if (elementBorderColor.operator==(color) || elementBackgroundColor.operator==(color)) {
             return true;
         }
     }
     return false;
 }
 
-
-LegendItem::LegendItem(const QPair<QString, QColor>& pair, LegendWidget * parent)
+LegendItem::LegendItem(const QPair<QString, QColor> &pair, LegendWidget *parent)
 {
-    QHBoxLayout *ItemLayout = new QHBoxLayout(this);
+    auto ItemLayout = new QHBoxLayout(this);
     ItemLayout->setContentsMargins(0, 0, 0, 0);
 
     if (pair.second.isValid()) {
@@ -188,14 +184,14 @@ LegendItem::LegendItem(const QPair<QString, QColor>& pair, LegendWidget * parent
         QPixmap LegendPixmap(20, height());
         LegendPixmap.fill(pair.second);
 
-        QLabel * LabelPixmap = new QLabel(this);
+        auto LabelPixmap = new QLabel(this);
         LabelPixmap->setPixmap(LegendPixmap);
         ItemLayout->addWidget(LabelPixmap);
 
         setFrameShape(QFrame::StyledPanel);
         setFrameShadow(QFrame::Sunken);
     }
-    QLabel * LegendLabel = new QLabel(this);
+    auto LegendLabel = new QLabel(this);
     LegendLabel->setText(pair.first);
     ItemLayout->addWidget(LegendLabel);
 
@@ -203,15 +199,18 @@ LegendItem::LegendItem(const QPair<QString, QColor>& pair, LegendWidget * parent
     setLayout(ItemLayout);
 }
 
-void LegendItem::enterEvent(QEvent* event)
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+void LegendItem::enterEvent(QEnterEvent *event)
+#else
+void LegendItem::enterEvent(QEvent *event)
+#endif
 {
     Q_EMIT legenItemHoovered(legendItemColor);
     QWidget::enterEvent(event);
 }
 
-void LegendItem::leaveEvent(QEvent* event)
+void LegendItem::leaveEvent(QEvent *event)
 {
     Q_EMIT legenItemHoovered(QColor());
     QWidget::leaveEvent(event);
 }
-
